# Change Log


[Unreleased](https://github.com/nteract/bookstore/compare/0.2.1...HEAD)

[2.1.0](https://github.com/nteract/bookstore/releases/tag/2.1.0)

[2.0.0](https://github.com/nteract/bookstore/releases/tag/2.0.0)

[0.1](https://github.com/nteract/bookstore/releases/tag/0.1)